.. module:: pymeasure.instruments.tdk

##########
TDK Lambda
##########

This section contains specific documentation on the TDK Lambda instruments that are implemented. If you are interested
in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.

.. toctree::
   :maxdepth: 2

   tdk_gen40_38
   tdk_gen80_65
